# win-pyxs

A python implementation of the Xenstore protocol for Windows using either the [WinPV](https://www.xenproject.org/developers/teams/windows-pv-drivers.html) or [GPLPV](https://wiki.xen.org/wiki/Xen_Windows_GplPv) drivers.

## Status

Very unfinished and not working yet. This is a work in progress and will be added to as and when I have the time.

## Background

Inspired by the work of [selectel](https://github.com/selectel/pyxs) and [JKDingwall](https://github.com/JKDingwall/pyxs/tree/windows) this project takes the work done by JKDingwall and splits it out into a separate module which is compatible with the latest version of pyxs.
